#
# spec file for package nfs-utils
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           nfs-utils
Version:        2.1.1
Release:        150100.10.32.1
Summary:        Support Utilities for Kernel nfsd
License:        GPL-2.0-or-later
Group:          Productivity/Networking/NFS
Url:            http://kernel.org/pub/linux/utils/nfs-utils/
Source0:        http://kernel.org/pub/linux/utils/nfs-utils/%{version}/nfs-utils-%{version}.tar.xz
# Download does not work:
# Source1:        ftp://nfs.sourceforge.net/pub/nfs/nfs.doc.tar.bz2
Source1:        nfs.doc.tar.bz2
Source4:        sysconfig.nfs
Source6:        README.NFSv4
Source7:        fw-client
Source8:        fw-server
Source11:       idmapd.conf
Source13:       nfs-utils.rpmlintrc
Source15:       nfsserver.service
Source16:       nfs.service
Source17:       nfs-server.nfsserver.conf
Source18:       nfs-client.nfs.conf
Source20:       nfs-mountd.options.conf
Source21:       nfs-server.options.conf
Source22:       rpc-gssd.options.conf
Source23:       rpc-statd.options.conf
Source24:       rpc-statd-notify.options.conf
Source25:       rpc-svcgssd.options.conf
Source26:       nfs.conf
Source27:       nfs-kernel-server.tmpfiles.conf
Patch0:         nfs-utils-1.0.7-bind-syntax.patch
Patch1:         0001-conffile-ignore-empty-environment-variables.patch
Patch2:         0002-mount-call-setgroups-before-setuid.patch
Patch3:         0003-nfs-server-generator-handle-noauto-mounts-correctly.patch
Patch4:         nsm-headers.patch
Patch5:         0002-Let-systemd-know-when-rpc.statd-is-needed.patch
Patch6:         0003-systemd-run-statd-notify-even-when-nfs-client-isn-t-.patch
Patch7:         0007-statd-user-from-sm
Patch8:         0008-gssd-replace-non-thread-safe-strtok-with-strsep.patch
Patch9:         0009-Convert-remaining-python-scripts-to-python3.patch
Patch10:        0010-gssd-Fix-locking-for-machine-principal-list.patch
Patch11:        0011-manpage-Add-a-description-of-the-nconnect-mount-opti.patch
Patch12:        0012-mountd-reject-unknown-client-IP-when-use_ipaddr.patch
Patch13:        0013-mountd-Don-t-proactively-add-export-info-when-fh-inf.patch
Patch14:        0014-mountd-update-man-page.patch
Patch15:        0015-mountd-add-logging-for-authentication-results-for-ac.patch
Patch16:        0016-mountd-add-cache-use-ipaddr-option-to-force-use_ipad.patch
Patch17:        0017-mountd-make-default-ttl-settable-by-option.patch
Patch18:        0018-Replace-all-var-run-with-run.patch
Patch19:        0019-gssd-use-mutex-to-protect-decrement-of-refcount.patch
Patch20:        0020-mountd-Initialize-logging-early.patch
Patch21:        0021-mount.nfs-insert-sloppy-at-beginning-of-the-options.patch
Patch22:        0022-mount.nfs-Fix-the-sloppy-option-processing.patch
Patch23:        0023-cache.c-removed-a-couple-warning.patch
Patch24:        0024-systemd-Apply-all-sysctl-settings-when-NFS-related-m.patch
Patch25:        0025-nfsdcltrack-getopt_long-fails-on-a-non-x86_64-archs.patch
Patch26:        0026-modprobe-avoid-error-messages-if-sbin-sysctl-fail.patch
Patch27:        0027-nfsd-allow-server-scope-to-be-set-with-config-or-com.patch

BuildRequires:  e2fsprogs-devel
BuildRequires:  fedfs-utils-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  tcpd-devel
BuildRequires:  pkgconfig(devmapper)
BuildRequires:  pkgconfig(kdb)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libnfsidmap) >= 0.24
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(mount)
BuildRequires:  pkgconfig(sqlite3)
Suggests:       python-base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
This package contains the NFS utilities. You can tune the number of
server threads via the sysconfig variable USE_KERNEL_NFSD_NUMBER. For
quota over NFS support, install the quota package.

%package -n nfs-client
Summary:        Support Utilities for NFS
Group:          Productivity/Networking/NFS
Requires:       keyutils
Requires:       netcfg
Requires:       rpcbind
Requires(post): %fillup_prereq
Requires(pre):  permissions
Requires(pre):  shadow
%if 0%{?suse_version} >= 1330
Requires(pre):  group(nogroup)
%endif
Obsoletes:      nfs-utils < 1.1.0

%description -n nfs-client
This package contains common NFS utilities which are needed for client
and kernel based server.

%package -n nfs-kernel-server
Summary:        Support Utilities for Kernel nfsd
Group:          Productivity/Networking/NFS
Requires:       netcfg
Requires:       nfs-client = %{version}
Requires:       rpcbind
Conflicts:      nfs-server
Provides:       nfs-utils = %{version}
Obsoletes:      nfs-utils < 1.1.0
PreReq:         permissions

%description -n nfs-kernel-server
This package contains support for the kernel based NFS server. You can
tune the number of server threads via the sysconfig variable
USE_KERNEL_NFSD_NUMBER. For quota over NFS support, install the quota
package.

%package -n nfs-doc
Summary:        Support Utilities for NFS
Group:          Productivity/Networking/NFS
Requires:       latex2html-pngicons
Obsoletes:      nfs-utils < 1.1.0

%description -n nfs-doc
This package contains additional NFS documentation.

%prep
%setup -q -a 1
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1

cp %{SOURCE6} .

%build
autoreconf -fvi
export CFLAGS="%{optflags} -fPIE"
export LDFLAGS="-pie"
%configure \
	--with-systemd \
	--enable-nfsv4 \
	--enable-gss \
	--enable-svcgss \
	--enable-ipv6 \
	--enable-nfsdcltrack \
	--enable-mount \
	--enable-libmount-mount \
	--enable-mountconfig
make %{?_smp_mflags}
cd nfs
for i in *.html ; do
sed -i \
 -e "s@%{_prefix}/lib/latex2html/icons.png/next_motif.png@%{_datadir}/latex2html/icons/next.png@" \
 -e "s@%{_prefix}/lib/latex2html/icons.png/up_motif_gr.png@%{_datadir}/latex2html/icons/up.png@" \
 -e "s@%{_prefix}/lib/latex2html/icons.png/previous_motif_gr.png@%{_datadir}/latex2html/icons/prev.png@" \
 $i
done

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
install -D -m 644 %{SOURCE15} %{buildroot}%{_unitdir}/nfsserver.service
install -D -m 644 %{SOURCE16} %{buildroot}%{_unitdir}/nfs.service
install -D -m 644 %{SOURCE17} %{buildroot}%{_unitdir}/nfs-server.service.d/nfsserver.conf
install -D -m 644 %{SOURCE18} %{buildroot}%{_unitdir}/nfs-client.target.d/nfs.conf
install -D -m 644 %{SOURCE20} %{buildroot}%{_unitdir}/nfs-mountd.service.d/10-options.conf
install -D -m 644 %{SOURCE21} %{buildroot}%{_unitdir}/nfs-server.service.d/10-options.conf
install -D -m 644 %{SOURCE22} %{buildroot}%{_unitdir}/rpc-gssd.service.d/10-options.conf
install -D -m 644 %{SOURCE23} %{buildroot}%{_unitdir}/rpc-statd.service.d/10-options.conf
install -D -m 644 %{SOURCE24} %{buildroot}%{_unitdir}/rpc-statd-notify.service.d/10-options.conf
install -D -m 644 %{SOURCE25} %{buildroot}%{_unitdir}/rpc-svcgssd.service.d/10-options.conf
install -D -m 644 %{SOURCE26} %{buildroot}%{_sysconfdir}/nfs.conf
install -D -m 644 %{SOURCE27} %{buildroot}%{_prefix}/lib/tmpfiles.d/nfs-kernel-server.conf
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcnfsserver
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcnfs-server
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcnfs
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcnfs-client
# sysconfig-data
mkdir -p %{buildroot}%{_fillupdir}
install -m 644 %{SOURCE4} %{buildroot}%{_fillupdir}
# idmapd setup
install -D -m 644 %{SOURCE11} %{buildroot}%{_sysconfdir}/idmapd.conf
mkdir -p -m 755 %{buildroot}%{_localstatedir}/lib/nfs/rpc_pipefs
mkdir -p -m 755 %{buildroot}%{_localstatedir}/lib/nfs/v4recovery
# sm-notify state
mkdir -p -m 755 %{buildroot}%{_localstatedir}/lib/nfs/sm
mkdir -p -m 755 %{buildroot}%{_localstatedir}/lib/nfs/sm.bak
touch %{buildroot}%{_localstatedir}/lib/nfs/state
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services
install -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/nfs-client
install -m 0644 %{SOURCE8} %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/nfs-kernel-server
install -m 644 utils/mount/nfsmount.conf %{buildroot}%{_sysconfdir}/nfsmount.conf
#
# hack to avoid automatic python dependency
chmod 644 %{buildroot}%{_sbindir}/{mountstats,nfsiostat}

%pre -n nfs-client
/usr/bin/getent passwd statd >/dev/null || \
	/usr/sbin/useradd -r -c 'NFS statd daemon' \
	-s /sbin/nologin -d %{_localstatedir}/lib/nfs -g nogroup statd
%service_add_pre nfs.service auth-rpcgss-module.service nfs-idmapd.service nfs-blkmap.service rpc-statd-notify.service rpc-gssd.service rpc-statd.service rpc-svcgssd.service

%post -n nfs-client
chown root:root %{_localstatedir}/lib/nfs > /dev/null 2>&1 || :
for i in sm sm.bak; do
	chown -R statd:nogroup %{_localstatedir}/lib/nfs/$i > /dev/null 2>&1 || :
done
### migrate from /var/lock/subsys
[ -d /run/nfs ] || mkdir /run/nfs
if [ -f %{_localstatedir}/lock/subsys/nfs-rpc.idmapd ]; then
	mv %{_localstatedir}/lock/subsys/nfs-rpc.idmapd /run/nfs
fi
if [ -f %{_localstatedir}/lock/subsys/nfsserver-rpc.idmapd ]; then
	mv %{_localstatedir}/lock/subsys/nfsserver-rpc.idmapd /run/nfs
fi
###
%{fillup_only -n nfs nfs}
#
%set_permissions /sbin/mount.nfs
%service_add_post nfs.service auth-rpcgss-module.service nfs-idmapd.service nfs-blkmap.service rpc-statd-notify.service rpc-gssd.service rpc-statd.service rpc-svcgssd.service

%preun -n nfs-client
%service_del_preun nfs.service auth-rpcgss-module.service nfs-idmapd.service nfs-blkmap.service rpc-statd-notify.service rpc-gssd.service rpc-statd.service rpc-svcgssd.service

%postun -n nfs-client
%service_del_postun nfs.service auth-rpcgss-module.service nfs-idmapd.service nfs-blkmap.service rpc-statd-notify.service rpc-gssd.service rpc-statd.service rpc-svcgssd.service

%verifyscript -n nfs-client
%verify_permissions -e /sbin/mount.nfs

%pre -n nfs-kernel-server
%service_add_pre nfsserver.service nfs-svcgssd.service nfs-mountd.service nfs-server.service

%preun -n nfs-kernel-server
%service_del_preun nfsserver.service nfs-svcgssd.service nfs-mountd.service nfs-server.service

%post -n nfs-kernel-server
### migrate from /var/lock/subsys
[ -d /run/nfs ] || mkdir /run/nfs
if [ -f %{_localstatedir}/lock/subsys/nfs-rpc.idmapd ]; then
	mv %{_localstatedir}/lock/subsys/nfs-rpc.idmapd /run/nfs
fi
if [ -f %{_localstatedir}/lock/subsys/nfsserver-rpc.idmapd ]; then
	mv %{_localstatedir}/lock/subsys/nfsserver-rpc.idmapd /run/nfs
fi
###
%service_add_post nfsserver.service nfs-mountd.service nfs-server.service
%tmpfiles_create nfs-kernel-server.conf
%set_permissions /var/lib/nfs/rmtab

%postun -n nfs-kernel-server
%service_del_postun nfsserver.service nfs-mountd.service nfs-server.service

%verifyscript -n nfs-kernel-server
%verify_permissions -e /var/lib/nfs/rmtab

%files -n nfs-client
%defattr(-,root,root)
%config %{_sysconfdir}/idmapd.conf
%config %{_sysconfdir}/nfsmount.conf
%config %{_sysconfdir}/nfs.conf
%verify(not mode) %attr(0755,root,root) /sbin/mount.nfs
/sbin/mount.nfs4
/sbin/umount.nfs
/sbin/umount.nfs4
/sbin/osd_login
%attr(0755,root,root) %{_sbindir}/mountstats
%attr(0755,root,root) %{_sbindir}/nfsiostat
%{_sbindir}/nfsidmap
%{_sbindir}/nfsstat
%{_sbindir}/rcnfs
%{_sbindir}/rcnfs-client
%{_sbindir}/rpc.gssd
%{_sbindir}/rpc.idmapd
%{_sbindir}/rpc.statd
%{_sbindir}/rpcdebug
%{_sbindir}/showmount
%{_sbindir}/sm-notify
%{_sbindir}/start-statd
%{_sbindir}/blkmapd
%{_sbindir}/rpc.svcgssd
%{_unitdir}/auth-rpcgss-module.service
%{_unitdir}/nfs-blkmap.service
%{_unitdir}/nfs-client.target
%{_unitdir}/nfs-idmapd.service
%{_unitdir}/nfs-utils.service
%{_unitdir}/rpc-gssd.service
%{_unitdir}/rpc-gssd.service.d
%{_unitdir}/rpc-gssd.service.d/10-options.conf
%{_unitdir}/rpc-statd-notify.service
%{_unitdir}/rpc-statd-notify.service.d
%{_unitdir}/rpc-statd-notify.service.d/10-options.conf
%{_unitdir}/rpc-statd.service
%{_unitdir}/rpc-statd.service.d
%{_unitdir}/rpc-statd.service.d/10-options.conf
%{_unitdir}/rpc-svcgssd.service
%{_unitdir}/rpc-svcgssd.service.d
%{_unitdir}/rpc-svcgssd.service.d/10-options.conf
%{_unitdir}/var-lib-nfs-rpc_pipefs.mount
%{_unitdir}/nfs.service
%dir %{_unitdir}/nfs-client.target.d
%{_unitdir}/nfs-client.target.d/nfs.conf
%dir /usr/lib/systemd/system-generators
/usr/lib/systemd/system-generators/nfs-server-generator
%dir /usr/lib/modprobe.d
/usr/lib/modprobe.d/50-nfs.conf
%{_mandir}/man5/nfsmount.conf.5%{ext_man}
%{_mandir}/man5/nfs.conf.5%{ext_man}
%{_mandir}/man5/nfs.5%{ext_man}
%{_mandir}/man7/nfs.systemd.7%{ext_man}
%{_mandir}/man8/mount.nfs.8%{ext_man}
%{_mandir}/man8/nfsidmap.8%{ext_man}
%{_mandir}/man8/nfsstat.8%{ext_man}
%{_mandir}/man8/rpc.sm-notify.8%{ext_man}
%{_mandir}/man8/showmount.8%{ext_man}
%{_mandir}/man8/sm-notify.8%{ext_man}
%{_mandir}/man8/umount.nfs.8%{ext_man}
%{_mandir}/man8/rpc.gssd.8%{ext_man}
%{_mandir}/man8/rpc.idmapd.8%{ext_man}
%{_mandir}/man8/gssd.8%{ext_man}
%{_mandir}/man8/idmapd.8%{ext_man}
%{_mandir}/man8/svcgssd.8%{ext_man}
%{_mandir}/man8/rpc.statd.8%{ext_man}
%{_mandir}/man8/rpcdebug.8%{ext_man}
%{_mandir}/man8/statd.8%{ext_man}
%{_mandir}/man8/mountstats.8%{ext_man}
%{_mandir}/man8/nfsiostat.8%{ext_man}
%{_mandir}/man8/blkmapd.8%{ext_man}
%{_mandir}/man8/rpc.svcgssd.8%{ext_man}
%{_fillupdir}/sysconfig.nfs
%dir %{_localstatedir}/lib/nfs
%dir %{_localstatedir}/lib/nfs/rpc_pipefs
%dir %{_localstatedir}/lib/nfs/v4recovery
%attr(0700,statd,nogroup) %dir %{_localstatedir}/lib/nfs/sm
%attr(0700,statd,nogroup) %dir %{_localstatedir}/lib/nfs/sm.bak
%ghost %{_localstatedir}/lib/nfs/state
%config %attr(0644,root,root) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/nfs-client

%files -n nfs-kernel-server
%defattr(-,root,root)
%{_unitdir}/nfs-mountd.service
%{_unitdir}/nfs-mountd.service.d
%{_unitdir}/nfs-mountd.service.d/10-options.conf
%{_unitdir}/nfs-server.service
%{_unitdir}/nfs-server.service.d
%{_unitdir}/nfs-server.service.d/10-options.conf
%{_unitdir}/proc-fs-nfsd.mount
%{_unitdir}/nfsserver.service
%{_unitdir}/nfs-server.service.d/nfsserver.conf
%{_prefix}/lib/tmpfiles.d/nfs-kernel-server.conf
%{_sbindir}/exportfs
%{_sbindir}/rcnfsserver
%{_sbindir}/rcnfs-server
%{_sbindir}/rpc.mountd
%{_sbindir}/rpc.nfsd
/sbin/nfsdcltrack
%{_mandir}/man5/exports.5%{ext_man}
%{_mandir}/man7/nfsd.7%{ext_man}
%{_mandir}/man8/exportfs.8%{ext_man}
%{_mandir}/man8/mountd.8%{ext_man}
%{_mandir}/man8/nfsd.8%{ext_man}
%{_mandir}/man8/rpc.mountd.8%{ext_man}
%{_mandir}/man8/rpc.nfsd.8%{ext_man}
%{_mandir}/man8/nfsdcltrack.8%{ext_man}
%config(noreplace) %{_localstatedir}/lib/nfs/etab
%config(noreplace) %{_localstatedir}/lib/nfs/rmtab
%config %attr(0644,root,root) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/nfs-kernel-server

%files -n nfs-doc
%defattr(-,root,root)
%doc nfs/*.html nfs/*.ps README.NFSv4

%changelog
* Mon Feb  6 2023 nfbrown@suse.com
- Rename all drop-in options.conf files as 10-options.conf
  This makes it easier for other packages to over-ride
  with a drop-in with a later sequence number.
  resource-agents does this.
  (bsc#1207843)
* Sat Jan 14 2023 nfbrown@suse.com
- 0026-modprobe-avoid-error-messages-if-sbin-sysctl-fail.patch
  Avoid modprobe errors when sysctl is not installed.
  (bsc#1200710 bsc#1207022 bsc#1206781)
- 0027-nfsd-allow-server-scope-to-be-set-with-config-or-com.patch
  Add "-S scope" option to rpc.nfsd to simplify fail-over cluster
  config.
  (bsc#1203746)
* Mon Sep  5 2022 nfbrown@suse.com
- add 0025-nfsdcltrack-getopt_long-fails-on-a-non-x86_64-archs.patch
  Fix nfsdcltrack bug that affected non-x86 archs.
  (bsc#1202627)
* Tue Jun 14 2022 nfbrown@suse.com
- 0024-systemd-Apply-all-sysctl-settings-when-NFS-related-m.patch
  Ensure sysctl setting work (bsc#1199856)
* Fri Apr  1 2022 nfbrown@suse.com
- Add 0023-cache.c-removed-a-couple-warning.patch
  Fix compilation with new glibc (SLE15-SP4)
  (bsc#1197788)
* Thu Mar 24 2022 nfbrown@suse.com
- Add 0021-mount.nfs-insert-sloppy-at-beginning-of-the-options.patch
  Add 0022-mount.nfs-Fix-the-sloppy-option-processing.patch
  Ensure "sloppy" is added correctly for newer kernels.  Particularly
  required for kernels since 5.6 (so SLE15-SP4), and safe for all kernels.
  (boo#1197297)
* Tue Jan 18 2022 nfbrown@suse.com
- Add 0020-mountd-Initialize-logging-early.patch
  If an error or warning message is produced before
  closeall() is called, mountd gets confused and doesn't work.
  (bsc#1194661)
* Fri May 21 2021 nfbrown@suse.com
- Add 0019-gssd-use-mutex-to-protect-decrement-of-refcount.patch
  A field was modified by multiple threads without locking.
  This can lead to use-after-free.
  (bsc#1183194)
* Fri May  7 2021 nfbrown@suse.com
- Add 0018-Replace-all-var-run-with-run.patch
  /var/run is long deprecated - switch all relevant paths to /run
  (bsc#1185170)
* Thu Mar 18 2021 nfbrown@suse.com
- 0012-mountd-reject-unknown-client-IP-when-use_ipaddr.patch
  0013-mountd-Don-t-proactively-add-export-info-when-fh-inf.patch
  0014-mountd-add-logging-for-authentication-results-for-ac.patch
  0015-mountd-add-cache-use-ipaddr-option-to-force-use_ipad.patch
  0116-mountd-make-default-ttl-settable-by-option.patch
  Improve logging of authentication (bsc#1181540)
* Thu Mar 18 2021 nfbrown@suse.com
- Add 0011-manpage-Add-a-description-of-the-nconnect-mount-opti.patch
  (bsc#1181651)
* Thu Mar 18 2021 nfbrown@suse.com
- Add 0010-gssd-Fix-locking-for-machine-principal-list.patch
  (bsc#1183194)
* Thu Sep  3 2020 nfbrown@suse.com
- 0009-Convert-remaining-python-scripts-to-python3.patch
  Python is no longer installed by default and these scripts
  work with python3, so request that explicitly.
  (bsc#1173104)
* Thu Jul  9 2020 nfbrown@suse.com
- 0008-gssd-replace-non-thread-safe-strtok-with-strsep.patch
  Fix bug with concurrent gssd requests arriving from kernel.
  (bsc#1174260)
* Mon Sep 30 2019 nfbrown@suse.com
- Don't make /var/lib/nfs owned by statd.
  Only sm and sm.bak need to be accessible by
  statd or sm-notify after they drop privs.
  Providing they get created, the parent
  directory can be root-owned.
- 0007-statd-user-from-sm
  Change rpc.statd and sm-notify to take uid from the sm
  directory.
  (bsc#1150733 CVE-2019-3689)
* Mon Dec  3 2018 nfbrown@suse.com
- 0002-Let-systemd-know-when-rpc.statd-is-needed.patch
  0003-systemd-run-statd-notify-even-when-nfs-client-isn-t-.patch
  Fixes for systemd integration
  (bsc#1116221)
- nfs.conf: spell NFSV4LEASETIME correctly.
  (bsc#1098532)
* Fri Jul  6 2018 kukuk@suse.de
- Create files in /var/lib/nfs via tmpfiles.d [bsc#1100404],
  [FATE#325524]
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Oct  6 2017 nfbrown@suse.com
- fix incorrect dependency in
  /usr/lib/systemd/system/nfs-client.target.d/nfs.conf
  When yast restarts "nfs" it should propagate to nfs-client,
  but doesn't.
  (boo#1053691)
* Wed Jul  5 2017 schwab@suse.de
- nsm-headers.patch: add missing <stdint.h>
* Tue May  2 2017 kukuk@suse.de
- Prerequire needed group "nogroup"
* Wed Feb  8 2017 nfbrown@suse.com
- update upstream version from 1.3.4 to 2.1.1
  The significant update is that configuration can
  now be read from a central /etc/nfs.conf file, and
  it can include other files such as /etc/sysconfig/nfs
  This means that the old nfs-config.service systemd
  unit is no longer needed.
- /etc/nfs.conf file created to import all sysconfig
  settings except *_OPTIONS directly into running code.
- dropins created to pass *_OPTIONS sysconfig setting to
  the various daemons.
- various specfile improvements, such as using "-D" in
  "install" commands, and adding "verify_permissions".
- "xtab" has not been needed for years and has now been remove.
- sysconfig.nfs updated, particular the ServiceRestart
  declarations have been tuned for systemd units.
- 0003-nfs-server-generator-handle-noauto-mounts-correctly.patch
  Fix the nfs-server-generator so that mounts marked "noauto"
  are not automatically mounted when NFS exported.
  (bsc#1019211)
- 0001-conffile-ignore-empty-environment-variables.patch
  0002-mount-call-setgroups-before-setuid.patch
  Other minor fixes found during testing.
- REMOVED 0001-Make-location-of-nfs-utils_env.sh-configurable.patch
  now included upstream
* Thu Jan 19 2017 jengelh@inai.de
- Check for existence of "statd" user before creating it,
  and do not suppress errors about it.
- Ensure units passed to %%service_* are full filenames.
- Pass all units (non-templated) to %%service_*.
* Mon Nov 14 2016 dimstar@opensuse.org
- Also ignore errors on the first chown call: this can happen
  especially in the build system when shadow is not present and
  the user has not been generated in the %%pre phase.
* Fri Oct 21 2016 nfbrown@suse.com
- move rpc.svcgssd and corresponding man page from
  nfs-client package to nfs-kernel-server.
  For NFSv4.0 this is needed on client as well as
  the server to support the back-channel.
  (bsc#1005609)
* Sun Aug 21 2016 nfbrown@suse.com
- 0001-Make-location-of-nfs-utils_env.sh-configurable.patch
  1.3.4 moved the config script location to somewhere
  that doesn't exist on openSUSE.  Move it somewhere
  better and install it there.
  (bsc#990356)
* Wed Aug 10 2016 nfbrown@suse.com
- nfs-utils-1.3.4.tar.xz
  New upstream release.  Lots of bugfixes, no significant
  functionality changes
- delete 0001-Fix-protocol-minor-version-fall-back.patch
  delete 0001-close-the-syslog-fd-in-daemon_init.patch
  delete 0001-mount-run-START_STATD-fully-as-root.patch
  delete 0001-mount.nfs-hide-EBUSY-errors.patch
  delete 0001-mount.nfs-trust-the-exit-status-of-start_statd.patch
  delete 0001-systemd-Decouple-the-starting-and-stopping-of-rpcbin.patch
  delete 0002-systemd-unit-files-fix-up-dependencies-on-rpcbind.patch
  delete nfs-utils-no-svcgss.service
  delete nfs-utils-uninit-mem.patch
  All patches are included in 1.3.4
* Tue Aug  9 2016 nfbrown@suse.com
- nfs-utils_env.sh
  Fix some problems with version_params.
  Various misspellings and remove the possiblity
  that V4 is both disabled and enabled.
  (bsc#990356)
* Mon Aug  8 2016 tchvatal@suse.com
- Drop OMC svcinfo file, nowdays useless
* Mon Aug  8 2016 tchvatal@suse.com
- Sort a bit with spec-cleaner to get uptodate spec
- Convert deps from regular devels to pkgconfig style
* Tue May 24 2016 nfbrown@suse.com
- 0001-systemd-Decouple-the-starting-and-stopping-of-rpcbin.patch
  0002-systemd-unit-files-fix-up-dependencies-on-rpcbind.patch
  Fix systemd dependencies to ensure rpcbind is started when needed.
  (bsc#975265)
* Thu Apr 21 2016 neilb@suse.com
- 0001-close-the-syslog-fd-in-daemon_init.patch
  Without this, tracing doesn't work
- 0001-mount.nfs-trust-the-exit-status-of-start_statd.patch
  (bsc#945937)
- 0001-mount-run-START_STATD-fully-as-root.patch
  (bsc#969152)
* Mon Apr  4 2016 kukuk@suse.de
- Drop unused BuildRequires for libgssglue, not used with tirpc
* Mon Apr  4 2016 kukuk@suse.de
- Drop unused BuildRequires for librpcsecgss, tirpc version is used
* Wed Mar  2 2016 neilb@suse.com
- 0001-mount.nfs-hide-EBUSY-errors.patch
  Stop "mount -a -t nfs" from complaining if filesystem
  already mounted (bsc#950340)
* Thu Feb 18 2016 neilb@suse.com
- 0001-Fix-protocol-minor-version-fall-back.patch
  (bnc#959211)
* Wed Feb 17 2016 neilb@suse.com
- nfs.service: don't mount/unmount nfs filesystems.
  systemd does this automatically.  Trying to do it here too
  causes timing races (boo#963616)
* Thu Nov 26 2015 schwab@suse.de
- nfs-utils-uninit-mem.patch: fix use of uninitialized memory (bsc#956743)
* Mon Nov  9 2015 p.drouand@gmail.com
- Remove sysvinit related macros; the package doesn't contain any
  sysvinit script
- Replace systemd with systemd-rpm-macros; increase dependencies
  weight
- Use %%configure macro
- Remove depreciated %%clean section
* Tue Oct 27 2015 jeffm@suse.com
- Use proper annotations for service restart (bsc#952055).
* Thu Oct 22 2015 nfbrown@suse.com
- update upstream version from 1.3.1 to 1.3.3.
  This contains lots of bugfixes but not significant new features.
- delete 0001-nfs-client.target-Removed-a-ordering-cycle-with-nfs-.patch
  delete 0002-Centralize-dependencies-on-the-auth-unit.patch
  both included upstream
- nfs-utils-no-svcgss.service
  fix minor make-install issue (has since been accepted upstream)
- use "make install" to install systemd files instead of hand-code.
- retain rpc-svcgssd for now until gss-proxy is packaged.
* Thu Oct 15 2015 nfbrown@suse.com
- nfs-utils_env.sh: honour RPC_PIPEFS_DIR setting.
  It is currently ignored due to a logic error.
  (bsc#947852)
* Thu Sep 24 2015 nfbrown@suse.com
- nfsserver.service.  Provide ExecReload directive.
  This allows "systemctl reload nfsserver" to work.
  PropagatesReloadTo but itself is not enough if this
  unit doesn't have it's own Reload handler.
  (bsc#97296)
* Thu Aug 13 2015 nfbrown@suse.com
- sysconfig.nfs: add STATD_PORT, STATD_HOSTNAME,
  LOCKD_TCPPORT, LOCKD_UDPPORT
- nfs-utils-env.sh: handle STATD_PORT, STATD_HOSTNAME,
  LOCKD_TCPPORT, LOCKD_UDPPORT
  Also handle NFSV4LEASETIME, which was missing.
  (bsc#941645)
* Mon Aug 10 2015 nfbrown@suse.com
- nfs.service: improve back-compatibility with /etc/init.d/nfs
  + mount and unmount nfs filesystems on start/stop.
  + keep status as "good" when everything is running.
  (bnc#911986)
* Sun Nov  9 2014 ledest@gmail.com
- fix bashisms in pre/post scripts
* Wed Nov  5 2014 nfbrown@suse.com
- new upstream nfs-utils-1.3.1
  This brings numerous fixes, particularly to gssd and
  nfsdcltrack.  It incorporates all the upstreamable
  patches we had:
- Delete  nfsdcltrack.sbin.patch
- Delete  start-statd.patch
- 0001-nfs-client.target-Removed-a-ordering-cycle-with-nfs-.patch
  0002-Centralize-dependencies-on-the-auth-unit.patch
  Patches from 1.3.2-rc, which look useful
- Convert from /etc/init.d startup scripts to full
  systemd integration.
  The upstream standard names are "nfs-client" and "nfs-server"
  rather than "nfs" and "nfsserver", so local "nfs" "nfsserver"
  aliases are created and "rcXXX" links are provided for all 4.
* Thu Sep  4 2014 nfbrown@suse.com
- nfsserver.init: allow $NFSD_V4_GRACE to set the lease
  time if NFSV4LEASETIME is not set, as some documentation
  suggests this.
  Also set NFSv4 and NLM grace time to make the NFSv4 lease time
  as having them different at boot time doesn't make sense.
  (bnc#892809)
* Mon Jul  7 2014 nfbrown@suse.com
- Remove mkintird scripts again.  "libguestfs" now includes
  them so nfs-utils doesn't need to.
  (bnc#883876)
* Thu Jun 26 2014 nfbrown@suse.com
- add mkinitrd scripts back in.  They are needed by
  "guestfs"  See bnc#883873
  (bnc#883876)
* Tue Jun 10 2014 nfbrown@suse.com
- Use start-statd and rpc-statd.service from upstream for running statd.
  Our start-statd doesn't work in a systemd environment (bnc#852984)
- start-statd.patch - needed to make upstream start-statd work properly.
- use .xz from upstream, that is what kernel.org prefers and it is smaller
* Wed Jun  4 2014 nfbrown@suse.com
- Remove 0001-nfsidmap-Keys-need-to-be-invalidated-instead-of-revo.patch
  Now that keyutils has been updated in Factory, this patch
  is no longer needed.
* Tue Jun  3 2014 werner@suse.de
- Check if systemd is listen on local socket 111 to trigger the
  start of the rpcbind.service on demand (bnc#860246)
- There exists only nfs-utils-1.3.0.tar.gz at
  http://kernel.org/pub/linux/utils/nfs-utils/1.3.0/
* Wed May 14 2014 nfbrown@suse.com
- New upstream version 1.3.0.
  Includes all our bugfix patches except 1.
  Adds assorted other bugfixes and improvements including
  initial support for NFSv4.2
  Prepares the way for better systemd integration.
  Discards useless programs gss_clnt_send_err and gss_destroy_creds
- Removes: 0001-mountd-Fix-is_subdirectory-again.patch
- Removes: 0002-gssd-Fix-recent-fix-to-Avoid-DNS-reverse-resolution-.patch
- Removes: 0003-Fix-handling-of-preferred-realm-command-line-option.patch
- Removes: 0004-nfsiostat-restore-output-format.patch
- Removes: 0005-gssd-don-t-give-up-on-machine-credential-if-hostname.patch
- Removes: 0006-gssd-fixed-typo-in-machine-cred-name.patch
- Removes: skip-on-ENOENT.patch
- Removes: mountd-fix-bug-affecting-exports-of-dirs-with-64bit-.patch
- Removes: exportfs-exit-with-error-code-if-there-was-any-error.patch
- Removes: exportfs-report-failure-if-asked-to-unexport-somethi.patch
- Removes: gssd-mount-hang-fix.patch
- Removes: udp-fallback-fix.patch
- Removes: fedfs-lib-name.patch
- 0001-nfsidmap-Keys-need-to-be-invalidated-instead-of-revo.patch
  This upstream patch is currently reverted until we get a newer version
  of keyutils.
* Tue May  6 2014 nfbrown@suse.com
- nfsdcltrack_sbin.patch
  The kernel expects nfsdcltrack to be in /sbin,
  so we must put it there.
* Wed Apr 16 2014 trenn@suse.de
- Remove mkinitrd bits -> we use dracut now which already has
  nfs stuff provided in its package in:
  /usr/lib/dracut/modules.d/95nfs/
  Remove sources:
  - mkinitrd-boot.sh
  - mkinitrd-setup.sh
* Tue Mar 11 2014 sleep_walker@suse.cz
- properly rename patches:
  udp-fallback.fix -> udp-fallback-fix.patch
  fedfs-lib-name -> fedfs-lib-name.patch
  gssd-mount-hang-fix -> gssd-mount-hang-fix.patch
* Sun Mar  9 2014 nfbrown@suse.com
- Remove "Start-Before: autofs" from nfs.init.  This turns
  out not to be needed, and is out of place.  If anything,
  autofs should declare a dependency on nfs. (bnc#861489)
- fedfs-lib-name, nfs-utils.spec
  Build with fedfs support so that if fedfs-utils is also
  installed, federated-filesystems can be exported.
  (FATE#313522)
* Mon Feb 17 2014 nfbrown@suse.com
- udp-fallback.fix: Fix fallback from tcp to udp
  (bnc#863749)
* Tue Feb  4 2014 nfbrown@suse.com
- nfs-utils.spec: Require keyutils for proper
  idmap lookup.
- nfs.init, nfsserver.init: mkdir /run/nfs before
  trying to create a file in there (bnc#859221)
- nfs.init, nfsserver.init: add
    X-Systemd-RemainAfterExit: true
  to ensure services aren't shutdown if sm-notify
  reports an error
  (bnc#849387)
* Wed Nov 27 2013 nfbrown@suse.com
- nfsserver.init: fix that typo properly.
  Somehow I only fixed part of the problem
  (bnc#849476)
* Tue Nov 26 2013 werner@suse.de
- If nfs-utils and autofs are both installed make sure that the nfs
  client boot service will be started before autofs as otherwise
  systemd dependency chain is waiting on nfs client services at
  shutdown if nfs client is enabled.
* Mon Nov 18 2013 nfbrown@suse.com
- nfsserver.init: fix typo in "--nfs-version 4".
  (bnc#849476)
* Sun Nov 17 2013 nfbrown@suse.com
- gssd-mount-hang-fix: An nfs mount will hang
  indefinitely if mounted by IP address and there
  is no reverse mapping available.  This is
  caused by a bug in gssd.
  (bnc#833543)
* Wed Nov  6 2013 nfbrown@suse.com
- nfs-utils.spec: add various systemd macros to make
  sure init scripts are registered properly
  bnc#845475
- nfs.int, nfsserver.init: run gssd on server as well
  as on client.  This is needed for NFSv4.0 callbacks.
  bnc#845269
- exportfs-exit-with-error-code-if-there-was-any-error.patch
- exportfs-report-failure-if-asked-to-unexport-somethi.patch
  Return good error code from exportfs.
  bnc#846064
* Tue Oct 22 2013 nfbrown@suse.com
- mountd-fix-bug-affecting-exports-of-dirs-with-64bit-.patch
  allow NFS export to work for XFS filesystems with INODE64
  (bnc#841971)
* Tue Oct 15 2013 nfbrown@suse.com
- nfs.init: run ldconfig directly rather than calling
  boot.ldconfig.
  boot.ldconfig had some "optimisations" which are
  unimportant and inconvenient for NFS, and doesn't
  exist any more anyway.
  (bnc#834164).
* Thu Sep  5 2013 nfbrown@suse.com
- nfs.init: always start gssd.
  Recent kernel change means that if gssd isn't running
  and NFSv4 mount will wait 15 seconds before timing out
  even if gss security wasn't requested.
  So just start gssd alway - there is no significant cost
  in this.
  (bnc#837262)
* Mon Sep  2 2013 nfbrown@suse.com
- skip-on-ENOENT.patch - suppress error message
  that isn't really an error (bnc#800414)
* Mon Aug  5 2013 ohering@suse.de
- Include also nfsv2,nfsv3,nfsv4.ko in initrd (bnc#815738)
- Remove usage of absolute paths in mkinitrd script
- Include also mount.nfs4
* Mon Jul 22 2013 nfbrown@suse.com
- New sysconfig variables
  NFS4_SERVER_MINOR_VERSION, GSSD_OPTIONS,
  NFS_GSSD_AVOID_DNS
  to enable various configurations.
- bug fixes to init scripts to avoid unmounting everything(!)
  and to avoid corrupting /run/nfs/bind.mounts
* Mon Jul 22 2013 nfbrown@suse.com
- New upstream release 1.2.8 - mostly bugfixes, many to gssd.
  No important new functionality
- Changes to ./configure command to remove warnings
- 8 more patches from upstream 'git' to fix non-trivial bugs
  including on CVE.
* Mon May 13 2013 coolo@suse.com
- remove sysvinit requires - they are rather harmful these days
* Wed Mar  6 2013 darin@darins.net
- nfsserver.init,sysconfig.nfs - Add support for setting rpc.mountd
  options.
* Wed Nov 28 2012 nfbrown@suse.com
- New upstream release 1.2.7.  Adds FedFD support
  to mounted and replaces nfsdcld with
  nfsdcltrack.  This is used to manage client state
  on NFSv4 servers.
  Incorporates more local patches.
- Replace "/var/run" with "/run" in various scripts.
- nfsserver.init: Generate message that "bind=" is deprecated
  if it is used.
* Wed Oct 17 2012 nfbrown@suse.com
- Add dependency on "netcfg" to ensure /etc/services
  is present (bnc#779851)
* Thu Sep 27 2012 nfbrown@suse.com
- nfs4-no-umount: does send MOUNT_UMNT rpcs
  when unmounting an 'nfs4' filesystem.  They
  are only required for nfs2,3. (bnc#772534)
* Thu Jul 19 2012 nfbrown@suse.com
- mount-exit-code.fix:  Correct exit code from
  unmount when fs is busy - allows autofs to work
  correctly. (bnc#770962)
* Thu May 17 2012 nfbrown@suse.com
- nfs upstream version 1.2.5.  Lots of bug fixes
  and improved support for pNFS.
  Adds nfsdcld daemon on osd_login script.
  Removed some very out-of-date documentation.
* Wed May  2 2012 nfbrown@suse.com
- nfsserver.init: remove VERSION_LIST. This is
  unnecessary duplication of VERSION_PARAMS
* Wed May  2 2012 nfbrown@suse.com
- nfsserver.init: Don't depend on "mount" preserving
  unknown options - it doesn't any more.  This can
  confuse nfsd_unbind_mounts (bnc#754805)
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Nov  6 2011 puzel@suse.com
- do not strip the binaries
* Wed Oct 12 2011 nfbrown@suse.com
- nfs.init: handle case where kernel adds trailing
  slash to name in /proc/mounts.
  (bnc#722431 bnc#720376)
* Sat Oct  1 2011 crrodriguez@opensuse.org
- Fix build in arm, portability bug, applications MUST
  use sysconf(_SC_PAGESIZE) instead of constant PAGE_SIZE
* Sun Sep 25 2011 nfbrown@suse.com
- New upstream version 1.2.5 - This adds a new binary
  blkmapd with man page,  This is part of PNFS support.
* Thu Aug 18 2011 nfbrown@novell.com
- New upstream version 1.2.4 - plus a few important
  patches from git.  This adds a new binary nfsidmap,
  with man page. Also: build with libmount enabled
  to correctly handle /etc/mtab being linked to
  /proc/self/mounts. (bnc#681106)
* Thu Jun 23 2011 nfbrown@novell.com
- nfs.init,nfsserver.init,sysconfig.nfs - Add support
  for configuring NFS for a fail-over configuration
  with shared state. (bnc#689622)
- rpc.mountd-segfault-fix; fix possible segfault caused
  by "showmount -e" usage. (bnc#693189)
- do-not-error-when-address-family-not-supported -
  suppress socket error when IPv6 is not loaded
  (bnc#670449)
- addmntent.fix - error check writes to /etc/mtab and
  cope accordingly. (bnc#689799)
- mount-catch-signals - don't abort on SIGXSFZ or other
  signals while mtab is locked (bnc#689799)
- mountd-auth-fix - fix bug that could give away incorrect
  access to NFS exported filesystems. (bnc#701702)
* Fri Jun 17 2011 aj@suse.de
- Fix URLs.
* Thu Jun  2 2011 nfbrown@novell.com
- nfsserver.init, sysconfig.nfs: add NFSV4LEASETIME
  parameter to allow lease time to be set.
  bnc#681510
* Tue May 31 2011 lnussel@suse.de
- use /var/run/nfs instead of /var/lock/subsys
* Tue May 31 2011 nfbrown@novell.com
- sysconfig.nfs: now that 'nfs' is not enabled
  by default, set NFS_START_SERVICES=yes by default
  and document that 'chkconfig nfs on' is needed.
* Wed Apr 27 2011 nfbrown@novell.com
- Make /var/lib/nfs world executable.
  Otherwise 'df' complains about /var/lib/nfs/rpc_pipefs
  bnc#675385
* Sat Mar 19 2011 jengelh@medozas.de
- Must up the loopback device, otherwise trying to contact the
  portmapper (even if it does not actually run) will hang forever-
  the TCP RST is crucial for mount.nfs
* Wed Feb 16 2011 nfbrown@novell.com
- nfs.init: improve handling of paths with spaces.
  If a path name has a space, it will appear as \040
  in fstab and in /proc/mounts.  Using 'grep -E' to search
  for this is problematic as it will interpret the
  '\'.  So use 'grep -F' instead - we know there is
  only a single space in /proc/mounts.  Also use
  "read -r" so 'read' doesn't interpret the '/'.
  (bnc#666128)
* Wed Feb 16 2011 nfbrown@novell.com
- nfsserver.init: make sure sm-notify runs on restart.
  If we stop nfsd, that might also stop lockd which would
  drop locks.  So make sure lockd really does drop lock
  for consistency, and ensure that sm-notify is run when
  nfsserver is restarted. (bnc#668280)
* Mon Jan 31 2011 lnussel@suse.de
- don't run SuSEfirewall2 from start-statd script. If SuSEfirewall2
  is installed and enabled it will be called at the end of the boot
  process anyways (bnc#668181).
* Fri Jan 28 2011 lnussel@suse.de
- avoid python depdency to avoid bloating the minimal installation
- use %%set_permissions instead of %%run_permissions
* Tue Jan 25 2011 lnussel@suse.de
- give user a hint if portmap isn't running as statd can't be started in that
  case.
* Wed Jan 12 2011 lnussel@suse.de
- don't enable nfs init script by default. The yast nfs module
  makes sure the script gets enabled when adding mounts
- print a message to tell when file systems are mounted as that
  could take a while
* Tue Dec  7 2010 coolo@novell.com
- add sysvinit prereqs to make sure the scripts are there before
  installation (also for building)
* Mon Oct 11 2010 nfbrown@novell.com
- new upstream version 1.2.3, plus some upstream fix-up patches.
- new user 'statd' owns /var/lib/nfs so rpc.statd runs as non-root.
- New commands 'mountstats' and 'nfsiostat'
- ipv6 support enabled as it is believed to be complete.
* Wed Aug 11 2010 nfbrown@novell.com
- Change "Requires: portmap" to "Requires: rpcbind".
  Current nfs-utils does not work properly with portmap
  due to IPv6 being enabled, so we really need rpcbind.
  So be explcit about that, else upgrading an old
  installation will leave portmap in place which
  won't work.
  bnc#620346
* Sun Jul 25 2010 aj@suse.de
- Add rpmlintrc since /var/lib/nfs/sm.bak is valid.
* Sun May  9 2010 nfbrown@novell.com
- nfsserver.init / sysconfig.nfs: allow NFSv3 service
  to be disabled so only NFSv4 can be used. bnc#598671
- nfs-v2-disable.patch: mountd support for above
- nfs.init: unmount bind mounts with '-l' to ensure they
    really unmount. bnc#598681
* Mon Apr 19 2010 nfbrown@novell.com
- mkinitrd-boot.sh: allow other mkinitrd-setup
  scripts to request the inclusion of nfs support
  by setting need_nfs to 1.  (bnc#572207)
* Mon Apr 19 2010 nfbrown@novell.com
- sysconfig.nfs, nfsserver.init, start-start: handle
  STATD_OPTIONS so that sysadmin can easily set options
  like port number. (bnc#595379)
* Fri Mar 26 2010 mmarek@suse.cz
- mkinitrd-boot.sh: Do not do anything over if iscsi should be used
  (bnc#590135).
* Tue Mar  9 2010 nfbrown@novell.com
- init.nfs: also call 'udevadm settle' when mounting things
  other than /usr and /opt. bnc#571540
* Tue Feb 23 2010 nfbrown@novell.com
- init.nfs: if mounting /usr fails, call "udevadm settle"
  and try again incase network interfaces are still
  appearing.  bnc#571540
* Sun Nov 29 2009 nfbrown@novell.com
- nfs-utils-eperm-fallback.patch:  mount.nfs
  tries a v3 mount after a v4 mount fails with ENOENT.
  Older linux nfsd servers return EPERM, so fall
  back in that case too.  bnc#557138
* Thu Nov  5 2009 nfbrown@novell.com
- New upsteam release - 1.2.1
  Includes new config file: /etc/nfsmount.conf and
  man page.
- nfs.init
  * implement try-restart in a more gentle fashion
  so that active mounts are not lost.  Also allow
  for the fact that binary has changed when finding
  and killing running daemons. (bnc#543911)
- start-statd
  * try-restart the firewall after starting statd
  as the firewall might need to update to reflect
  a new port number.
- Start nfs services if any nfs related sysctl
  is set in /etc/sysctl.conf
* Fri Oct 30 2009 nfbrown@suse.de
- Kill processes on NFS mounts when unmounting
  for shutdown.  This allows any 'sync' to happen
  before we turn off the network.
  (bnc#503640)
* Tue Oct  6 2009 werner@suse.de
- Work around broken sysconfig file (bnc#529961)
* Fri Mar 20 2009 nfbrown@suse.de
- sysconfig.nfs
  * add 'NFS_START_SERVICE' option for people who
  need gssd or idmapd but mount using automount, not
  fstab. bnc#472438
* Wed Dec 17 2008 nfbrown@suse.de
- nfs.init
  * 'stop' should stop servies based on what is
  running, not what is configured to be run.
  bnc#459021
  * force-start added to start NFS services even
  if nothing is in /etc/fstab.
* Mon Dec  8 2008 bwalle@suse.de
- initrd: Giving the DHCP provided root path a higher priority
  compared to the fallback from fstab. Command line can still
  overwrite the DHCP provided root path. (bnc #440192).
* Sun Dec  7 2008 nfbrown@suse.de
- gssd-mem-leak
  * set better expiry date for cached auth info
  so kernel does not run out of memory
  bnc#442490
* Fri Dec  5 2008 nfbrown@suse.de
- nfs.init
  * Don't signal an error if asked to stop 'nfs'
  when there is nothing to stop.  Signalling an
  error here causes "rpm -e nfs-client" to fail.
  (bnc#450940)
* Tue Dec  2 2008 nfbrown@suse.de
- warn-nfs-udp.patch
  * Add warnings to nfs.man about usage of UDP
  and print message pointing to this warning
  when udp is used.
  This comes from util-linux-warn-nfsudp.diff in
  previous releases.
- nfs.init
  * load nfs modules then apply any sysctl setting
    before mounting any filesystems
    (bnc#431306, bnc#443118)
- nfsserver.init
  * set lockd sysctls before starting lockd.
    (bnc#443118)
* Tue Nov 25 2008 nfbrown@suse.de
- nfs.init
  * Don't 'stop' if root is on NFS.
  If we stop NFS if root is on NFS, then
  reboot will hang - bnc#439974
* Sun Nov 23 2008 nfbrown@suse.de
- nfs.init
  * Don't try to kill processes with fuser.
  it hangs when netowrk is down, and isn't
  needed as we use lazy unmount
  bnc#445908
  * Don't kill statd if nfsd is still running.
- fork-start-statd.patch
  * Don't use 'system' to run start-statd
  as this looses our setuid bit.
  bnc#447812
* Fri Nov 21 2008 hare@suse.de
- export ROOTFS_FSCK=0 to skip fsck for root on NFS (bnc#441234)
* Thu Nov 20 2008 nfbrown@suse.de
- rpc.gssd-catch-signal.patch
  * new patch (not yet upstream) to make sure
    rpc.gssd gets signals from dnotify.
    bnc#406832
* Wed Nov 19 2008 nfbrown@suse.de
- sm-notify-no-sync.patch
  * new upstream patch to avoid sync() in common
    case of no peers to notify.
    Important for speeding boot of SLED
* Tue Nov 18 2008 nfbrown@suse.de
- nfs-utils.spec: typo in command to install
  modprobe.d/nfs-utils
* Fri Nov 14 2008 nfbrown@suse.de
- nfsserver.init
  * don't set version if nfsd already running.
    doing that causes unhelpful error when trying
    to start nfsserver when it is already running.
    (bnc#427330)
- modprobe.nfs-utils
  * arrange that when various nfs modules are loaded
    the relevant values from /etc/sysctl.conf are set
    (bnc#431306, bnc#443118)
* Fri Nov  7 2008 nfbrown@suse.de
- nfs.init
  * fix typo in handling of "init.d/nfs status"
    $status should have been $state
* Mon Oct 13 2008 mkoenig@suse.de
- nfs.init:
  * ensure all daemons get killed on stop (including rpc.statd)
  * unmount rpc_pipefs
  * let close_usr do the work before the NFS filesystems get unmounted
* Mon Oct 13 2008 ro@suse.de
- fix sysconfig filename for changed fillup call
* Mon Oct  6 2008 kukuk@suse.de
- Disable IPv6, completly broken [bnc#431542]
* Mon Sep 29 2008 kukuk@suse.de
- Enable IPv6 [bnc#429853]
* Fri Sep 26 2008 nfbrown@suse.de
- Fix nfs.init to check for portmap or rpcbind properly.
  Either or both can be installed, but as long as one is
  running, neither 'start' or 'status' will complain.
  bnc#428436
* Mon Sep 22 2008 nfbrown@suse.de
- Change nfs.init to do nothing if NFS is not mentioend in /etc/fstab,
  and sure it is always enabled.  bnc#331667
* Mon Sep 22 2008 nfbrown@suse.de
- Improve Description fields in fw-server and fs-client.
  bnc#424432 bnc#424433
* Tue Sep 16 2008 mrueckert@suse.de
- require libevent-devel on 11.1 or newer
* Wed Sep  3 2008 hare@suse.de
- Call mkinitrd_setup during %%post and %%postun (bnc#413709)
* Mon Aug 18 2008 mrueckert@suse.de
- remove outdated options in the fillup_and_insserv call
* Fri Aug 15 2008 nfbrown@suse.de
- upgrade to nfs-utils-1.1.3
  - assorted bugfixes including some that we have fixed in our 1.1.2
    release
  - some work towards client-side IPv6 support
- Remove included patches.
- Add patches that are still not upstream
  They relate to mounting from server which does not listen
  to UDP for portmap
* Wed Aug 13 2008 werner@suse.de
- Fix boot script and use correct Stop tags
- The nfs boot script uses lazy umount and terminates process
  on shutdown in case of causing busy mounts
- The nfs boot script may parse /etc/fstab only once
* Wed Jul 23 2008 hare@suse.de
- Include mkinitrd scriptlets.
- Do not install Makefiles for nfs-doc.
* Tue Jul 15 2008 nfbrown@suse.de
- nfs.init - parse /etc/fstab correctly.  The first two fields
  are "what where", not "where what" (bnc#364513)
* Fri Jun 27 2008 schwab@suse.de
- Use autoreconf.
* Fri Jun  6 2008 nfbrown@suse.de
- nfs-utils-1.1.2-start-statd.patch - fix so that statd isn't
  required with "-o remount" (that causes a problem with
  nfs-root (bnc#397417)) and isn't required for nfsv4.
* Mon Jun  2 2008 lnussel@suse.de
- fix permissions handling of mount.nfs (bnc#304318)
- fix prereqs
* Wed May 14 2008 schwab@suse.de
- Fix some lost exit status in init scripts.
* Tue May  6 2008 nfbrown@suse.de
- nfs-utils-1.1.2-start-statd.patch - statd needs to be started
  when using 'string' options to kernel was well as when using
  binary options.
* Fri May  2 2008 nfbrown@suse.de
- Added SM_NOTIFY_OPTIONS sysconfig - (bnc #379806)
- Removed needless rc_status/rc_exit games in nfsserver.init (bnc #380156)
- Fixed some sysconfig entries that asked to restart non-existent
  services (gssd and idmpad have been rolled in to nfs/nfsserver).
* Fri Apr 11 2008 jsrain@suse.cz
- fixed more bugs in port information for SuSEfirewall2 (bnc #373969)
* Wed Apr  9 2008 jsrain@suse.cz
- fixed typo in port information for SuSEfirewall2 (bnc #373969)
* Tue Apr  1 2008 mkoenig@suse.de
- fix path srvinfo.d -> svcinfo.d
- remove svcinfo.d dir as it is provided now by filesystem
* Thu Mar 27 2008 mkoenig@suse.de
- update to version 1.1.2
- uses libgssglue instead of libgssapi
- remove patch
  nfs-utils-o_create-mode
* Wed Mar 26 2008 mkoenig@suse.de
- add rpcbind support [fate#300607]
* Thu Feb 28 2008 ro@suse.de
- added gssapi to buildrequires
* Wed Feb 13 2008 jeffm@suse.com
- Cleaned up open(O_CREAT) without file permissions.
* Mon Dec 17 2007 nfbrown@suse.de
- Fix sed script used to create bind mounts for NFSv4 export
  (#279665)
- Fail nfs.init if portmap is not running.  Normally it will be,
  but if it isn't nfs can fail strangely. (#325763)
* Mon Dec 17 2007 nfbrown@suse.de
- Add SuSEfirewall2 config files for nfs-client and nfs-kernel-server
  (#247354)
* Mon Nov 12 2007 ro@suse.de
- use navigation icons from latex2html in nfs-utils-doc package
  (#116355)
* Fri Sep 14 2007 ro@suse.de
- use "--no-nfs-version 4" for nfsd and mountd if
  NFS4_SUPPORT is set to "no" (#308661)
* Wed Sep 12 2007 ro@suse.de
- drop conflicts with nfs-server (userspace) in nfs-client package
  showmount has been removed there (#309782)
* Thu Jul 19 2007 ro@suse.de
- added README.NFSv4 (#182775)
* Tue Jul 17 2007 meissner@suse.de
- buildrequire nfsidmap-devel
* Fri Jun 22 2007 ro@suse.de
- added split-provides for nfs-client to get nfs-client installed
  on update from older versions where this was in aaa_base (#286743)
* Mon Jun 11 2007 mkoenig@suse.de
- add Obsoletes
* Tue Jun  5 2007 mkoenig@suse.de
- update to version 1.1.0:
- package mount.nfs, umount.nfs to replace dropped nfs code
  from util-linux mount.
- removed patches:
  nfs-utils-noroot.patch
  nfs-utils-gssd-select-ccache.patch
  nfs-utils-krb5.patch
- Package split: nfs-common, nfs-server and nfs-doc
- adjust init scripts
- remove old Obsoletes/Provides:
  nfsutils (last used 2001)
  knfsd (last used 2000)
  linuxnfs (last used 1999)
* Tue Feb 27 2007 ro@suse.de
- update to 1.0.12
  - Fix -n option to mountd
  - Document sensitive gids
- upstreamed patches deleted:
  nfs-utils-anon-uid32.patch
- added e2fsprogs-devel (for libblkid)
- nhfsXXX binaries and manpages have been removed upstream
* Thu Jan 11 2007 ro@suse.de
- moved omc xml file to /usr/share/omc and removed config tag
* Mon Jan  8 2007 ro@suse.de
- move srvinfo.d to svcinfo.d (typo in fate entry)
- Added handling for NFSv4 bind mounts in init script (#229583)
* Mon Dec 18 2006 ro@suse.de
- added nfsserver.xml to /etc/omc/srvinfo.d (fate#301835)
* Tue Aug  8 2006 ro@suse.de
- update to 1.0.10
  remove upstreamed patches:
  - nfs-utils-1.0.6-anon-exports.patch
  - export-acl.diff
  - nfs-utils-1.0.6-dep.patch
  - nfs-utils-1.0.6-doc.patch
  - nfs-utils-1.0.7-CITI_NFS4_ALL-2.dif
  - nfs-utils-1.0.7-destdir.patch
  - nfs-utils-1.0.7-gssapi.patch
  - nfs-utils-1.0.7-headtail.patch
  - nfs-utils-1.0.7-mount_type3.patch
  - nfs-utils-1.0.7-no_sync_warn_ro.patch
  - nfs-utils-1.0.7-rpcgen.patch
  - nfs-utils-1.0.7-strip.patch
  - nfs-utils-64bigendian.patch
  - nfs-utils-1.0.6-quota.patch (upstream different)
  partly upstreamed patches:
  - nfs-utils-1.0.6-anon-uid32.patch
  - nfs-utils-1.0.7-gssd-select-ccache.patch
  redone patches:
  - nfs-utils-noroot.patch (was: norootforbuild.diff)
  - pass -fPIE to configure instead of patch
* Thu Jul 13 2006 aj@suse.de
- Fix off-by-one error in rpcgen.
* Fri Jun 23 2006 ro@suse.de
- find kerberos ticket files even if /tmp on reiser (#187775)
* Wed Jun 21 2006 ro@suse.de
- fix /etc/gssapi_mech.conf for lib64 platforms (#186954)
* Mon Jun 12 2006 ro@suse.de
- added support for type 3 filehandles to mountd (#182552)
* Fri Jun  2 2006 ro@suse.de
- disable v4 support in rcnfsserver if NFS4_SUPPORT is
  not set to "yes" (#178633)
* Fri Jun  2 2006 ro@suse.de
- added fix for 64bit bigendian platforms in gssd (#172605)
* Tue May  2 2006 okir@suse.de
- gracefully handle repeated "rcidmapd stop" calls (#169087)
* Mon Apr 24 2006 ro@suse.de
- nfs-server rc-script: make force-reload do as reload does
  (#167152)
- nfs-server rc-script: reload idmapd if NFSV4 is on (#167016)
* Thu Mar 23 2006 okir@suse.de
- Make gssd and svcgssd scripts mount rpc_pipefs if not there
  (#158000) and added "Should-start: krb5kdc" to make sure
  the KDC is started first if running on the same server (#159980)
* Tue Jan 31 2006 okir@suse.de
- Load RPCSEC_GSS kernel modules in rcgssd/rcsvcgssd init
  scripts (#142352)
- Enable NFSv4 by default
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 ro@suse.de
- nfsserver rcscript: only mount nfsdfs if not mounted already
* Mon Jan 16 2006 schwab@suse.de
- Don't strip binaries.
* Mon Dec 19 2005 mmj@suse.de
- fix filelist
* Mon Nov 28 2005 ro@suse.de
- fix init scripts: in the stop case, a not running service
  is not an error (#134904)
* Mon Nov 14 2005 ro@suse.de
- packaging /var/lib/nfs/v4recovery directory (#133502)
* Thu Sep  1 2005 okir@suse.de
- packaging /var/lib/nfs/rpc_pipefs directory (#114103)
* Thu Aug 25 2005 ro@suse.de
- modify nfs-server script to support uml case (#86624)
* Fri Aug 19 2005 okir@suse.de
- added NFS4_SUPPORT and NFS_SECURITY_GSS to sysconfig.nfs
- updated the idmapd script so it honors NFS4_SUPPORT
- updated gssd script so it honors NFS_SECURITY_GSS
- added svcgssd script
* Mon Jun 20 2005 ro@suse.de
- fix in init-script (do not try unmount if not mounted) (#91460)
* Mon Jun  6 2005 schwab@suse.de
- Install correct init script.
* Fri Jun  3 2005 kukuk@suse.de
- Compile with -fpie/-pie
* Tue May 31 2005 okir@suse.de
- Enabled NFSv4 and RPCSEC_GSS support
* Tue Apr 19 2005 ro@suse.de
- do not warn about sync/async for readonly exports (#78369)
* Sun Apr  3 2005 ro@suse.de
- make it build with gcc4
* Sat Feb  5 2005 schwab@suse.de
- Update to nfs-utils 1.0.7.
- Make non-anonymous exports work again.
- Use BuildRoot.
* Mon Dec 13 2004 ro@suse.de
- update to 1.0.7-pre2 (use 1.0.6.2 as package version)
- disable gss and nfsv4 for now
* Thu Dec  9 2004 okir@suse.de
- make anonymous exports work again (#46918)
* Mon Aug 30 2004 ro@suse.de
- added sysconfig variable to allow running mountd on a
  defined port
* Mon Aug 30 2004 okir@suse.de
- Fix to prevent mountd from crashing on kernel upcalls
* Fri Aug 27 2004 okir@suse.de
- Fix a permission problem after using exportfs -u
* Tue Aug 24 2004 ro@suse.de
- remove "exportfs -au" from rcnfsserver stop
  (kernel zaps table on last server exit anyway) (#44049)
* Thu Jun 24 2004 ro@suse.de
- added patch from okir to use nobody:nogroup again by default
  for anonymous (#42288)
* Tue Jun 22 2004 ro@suse.de
- remove nfslock start script
- remove nfslock dependency
* Thu Jun 17 2004 ro@suse.de
- mount nfsd filesystem if possible (#41955)
* Wed Mar 31 2004 mmj@suse.de
- Remove unpackaged files
* Wed Mar 31 2004 mmj@suse.de
- Move sm-notify to util-linux [#36737]
* Fri Mar 26 2004 ro@suse.de
- remove rpc.statd completely
- add sm-notify and call it first in nfslock script (#36737)
* Tue Feb  3 2004 ro@suse.de
- disable rquotad already in configure
  (no need to compile it, if we only remove it later)
* Tue Jan 20 2004 okir@suse.de
- Include patch that allows Sun boxes to mount large files
* Mon Sep 15 2003 ro@suse.de
- update to version 1.0.6 to fix a possible segfault in statd
- support for 2.6 kernels
* Fri Aug 29 2003 ro@suse.de
- fix hed/tail calling syntax (#29644)
* Mon Aug 25 2003 ro@suse.de
- add restart_on_update/stop_on_removal macros
* Fri Aug 15 2003 ro@suse.de
- added sysconfig metadata (#28908)
* Mon Aug  4 2003 ro@suse.de
- fix compile for rquotad (unused anyway
* Thu Jul 31 2003 ro@suse.de
- add support for STATD_HOSTNAME (#28201)
* Mon Jul 28 2003 ro@suse.de
- update to 1.0.5 and adapt patches
- overflow patch already included
- part of acl patch already included
* Mon Jul 21 2003 agruen@suse.de
- Switch to officially reserved bit flag for `no_acl' export
  option: the previous bit was already allocated.
* Tue Jul  8 2003 agruen@suse.de
- Add `no_acl' export option, replaces the nfs_permission_mode
  nfsd module parameter.
* Tue Jul  8 2003 okir@suse.de
- Fixed off-by-one overflow (#27744)
* Thu Jun 12 2003 kukuk@suse.de
- Add /var/lib/nfs to filelist
* Mon May 12 2003 ro@suse.de
- fix file list
* Fri Mar 28 2003 ro@suse.de
- update to 1.0.3
* Wed Jan  8 2003 ro@suse.de
- added sysconfig metadata (#22663)
* Fri Sep  6 2002 ro@suse.de
- rcnfsserver: moved ypbind to should-start (#18952)
- rcnfslock: fixed typo killing daemons on "status" (#19046)
* Tue Sep  3 2002 ro@suse.de
- changed nfslock from should-start to required-start in
  nfsserver rc script (is in the same package anyway)
* Mon Aug 26 2002 okir@suse.de
- Fixed minor manpage issue (#18326)
* Thu Aug 22 2002 ro@suse.de
- fixed symlink rcnfslock (#18171)
* Wed Aug  7 2002 ro@suse.de
- move statd and lockd to their own startscript (#17425)
* Thu Aug  1 2002 ro@suse.de
- update to 1.0.1
- added prereqs
* Thu Jul 25 2002 okir@suse.de
- Help users who do not configure a domain name: when
  sending out NSM_NOTIFY strip off .local suffix if
  present.
* Mon Jul 22 2002 okir@suse.de
- partial fix for http://bugzilla.suse.de/show_bug.cgi?id=16957
  (missing NSM_NOTIFY call when rebooting).
* Tue Jul 16 2002 kukuk@suse.de
- Don't source rc.config (#17025)
* Thu Jun 13 2002 ro@suse.de
- run suse_update_config
* Tue Feb 26 2002 ro@suse.de
- fixed wrong quotes in init-script (#13939)
* Wed Feb  6 2002 ro@suse.de
- ignore returncodes from killing statd and lockd (#13072)
* Wed Feb  6 2002 ro@suse.de
- sysconfig/nfs-server -> sysconfig/nfs
* Wed Jan  9 2002 ro@suse.de
- removed variable NFS_SERVER (#12742)
- moved USE_KERNEL_NFSD_NUMBER to /etc/sysconfig/nfs-server
* Wed Sep 26 2001 ro@suse.de
- up to 0.3.3
  many fixes to canonicalize hostnames in exports
* Fri Aug 24 2001 ro@suse.de
- removed nfs-version 3 detection in start-script, all kernels
  that have kernel nfsd support usually do have nfsd-v3 support
  and detection would require at least a 5 sec wait in the script
* Tue Jul 31 2001 kukuk@suse.de
- Fix path to init script in description [Bug #9494]
- Fix comment in runlevel section [Bug #9561]
- Make init script LSB conform [Bug #9073]
* Wed Apr 11 2001 ro@suse.de
- lockd only started for 2.2 kernels instead of ignoring error
- completed rpc.statd to /sbin move in startscript
* Mon Mar 12 2001 ro@suse.de
- move rpc.lockd, rpc.statd to /sbin
* Mon Mar 12 2001 ro@suse.de
- update to 0.3.1
- ignore lockd error messages
- dump filedescriptors before starting kernel threads
* Tue Feb  6 2001 ro@suse.de
- renamed package to nfs-utils
- Obsoletes and Provides nfsutils
* Fri Jan 12 2001 ro@suse.de
- fixed conflicts: nfs-server (#5548)
* Thu Jan 11 2001 ro@suse.de
- don't fail if lockd can't be started
* Wed Dec  6 2000 bk@suse.de
- fix broken symlinks for %%{_mandir}/rpc.{nfs,mount,stat}d.8.gz
* Tue Nov 28 2000 kukuk@suse.de
- Move new initscript to /etc/init.d
* Thu Oct 12 2000 ro@suse.de
- exports.4 should be exports.5
- removed k-prefix
* Thu Oct 12 2000 ro@suse.de
- added exports.4 man-page
- up to 0.2.1
* Wed Sep 27 2000 ro@suse.de
- update to 0.2
- fix for nfsserver.init (check for v3)
* Thu Aug 17 2000 ro@suse.de
- ugraded from knfsd to successor package nfs-utils (v.0.1.9.1)
* Fri Jul 28 2000 bjacke@suse.de
- fixed checkproc call in init script
* Fri Jul 21 2000 kukuk@suse.de
- Fix missing format string in syslog call (next rpc.statd security
  problem)
* Wed Jul 19 2000 kukuk@suse.de
- Fix problem with NULL h_alias field (rpc.statd security problem)
* Thu Jun 22 2000 kukuk@suse.de
- Change conflict from itself to nfsserv
* Tue Apr 18 2000 kukuk@suse.de
- Fix rcnfsserver link
* Sat Apr 15 2000 kukuk@suse.de
- Add rc.config variables and init script from aaa_base
* Wed Feb 16 2000 kukuk@suse.de
- Fill out Copyright and Group field
- Remove rquotad from file list, it is already in the quota
  package [Bug 1571]
* Tue Jan 25 2000 ro@suse.de
- manpages to /usr/share using macro
* Wed Oct 20 1999 ro@suse.de
- renamed package from linuxnfs to knfsd
* Tue Oct 12 1999 garloff@suse.de
- Fixed filelist (%%ghost)
* Tue Oct 12 1999 garloff@suse.de
- upgraded to knsfd-1.5.2. Added klockd to file list.
  Ditto for new /dev/nfsd_netlink.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug 24 1999 uli@suse.de
- added -fsigned-char to CFLAGS (PPC)
* Sat Jul 17 1999 ro@suse.de
- update to 1.4.6
* Mon Jun 14 1999 kukuk@suse.de
- update to version 1.4
* Sun Jun  6 1999 kukuk@suse.de
- update to version 1.3.3b
* Tue Mar 16 1999 ro@suse.de
- update to version 1.2
* Thu Nov 26 1998 ro@suse.de
- update to 981122
* Thu Nov 12 1998 ro@suse.de
- use lx_hack
* Wed Oct 21 1998 ro@suse.de
- added bugfix for statd (by HJL)
* Tue Oct 20 1998 ro@suse.de
- update to knfsd-981014
* Mon Sep 28 1998 ro@suse.de
- initial package / for use a 2.1 kernel with knfsd support is needed
